summaryrefslogtreecommitdiffstats
path: root/kshowmail/kshowmailview.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
commit9c02dbb59ce57c68dc177d9294b980bf114a3e11 (patch)
treeb1b40423c9be9a42a97cd0e8f3af3139aefb6fa0 /kshowmail/kshowmailview.h
parent0b875800e452c97b1a3f25aba5f029a8c33a4b93 (diff)
downloadkshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.tar.gz
kshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.zip
Update to TDE R14 API
Diffstat (limited to 'kshowmail/kshowmailview.h')
-rw-r--r--kshowmail/kshowmailview.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/kshowmail/kshowmailview.h b/kshowmail/kshowmailview.h
index e417e2e..8e3607c 100644
--- a/kshowmail/kshowmailview.h
+++ b/kshowmail/kshowmailview.h
@@ -24,16 +24,16 @@
#include <config.h>
#endif
-//Qt headers
-#include <qwidget.h>
-#include <qsplitter.h>
-#include <qcursor.h>
-#include <qpopupmenu.h>
+//TQt headers
+#include <ntqwidget.h>
+#include <ntqsplitter.h>
+#include <ntqcursor.h>
+#include <ntqpopupmenu.h>
//KDE headers
-#include <klistview.h>
-#include <kconfig.h>
-#include <kapplication.h>
+#include <tdelistview.h>
+#include <tdeconfig.h>
+#include <tdeapplication.h>
//KShowmail headers
#include "configlist.h"
@@ -45,7 +45,7 @@ class ConfigList;
class KshowmailDoc;
/** The KshowmailView class provides the view widget for the KShowMailApp instance.
* The View instance inherits QWidget as a base class and represents the view object of a KMainWindow.
* As KshowmailView is part of the document-view model, it needs a reference to the document object
* connected with it by the KShowMailApp class to manipulate and display
* the document structure provided by the KshowmailDoc class.
@@ -54,7 +54,7 @@ class KshowmailDoc;
* @author Ulrich Weigelt <ulrich.weigelt@gmx.de>
* @version KDevelop version 0.4 code generation
*/
-class KshowmailView : public QSplitter
+class KshowmailView : public TQSplitter
{
Q_OBJECT
@@ -63,7 +63,7 @@ class KshowmailView : public QSplitter
/**
* Constructor for the main view
*/
- KshowmailView(QWidget *parent = 0, const char *name=0);
+ KshowmailView(TQWidget *parent = 0, const char *name=0);
/**
@@ -74,7 +74,7 @@ class KshowmailView : public QSplitter
/**
* Saves the options
*/
- void saveOptions( KConfig* config );
+ void saveOptions( TDEConfig* config );
/**
* Clears the mail list view.
@@ -96,7 +96,7 @@ class KshowmailView : public QSplitter
* @param time send date, formated to the ISO 8601 extended specification (YYYY-MM-DDTHH:MM:SS)
* @return pointer to the created list view item
*/
- ShowListViewItem* insertMail( QString& number, QString& account, QString& from, QString& to, QString& subject, QString& date, QString& size, QString& content, QString& state, QString& time );
+ ShowListViewItem* insertMail( TQString& number, TQString& account, TQString& from, TQString& to, TQString& subject, TQString& date, TQString& size, TQString& content, TQString& state, TQString& time );
/**
* Refreshes the geometry.
@@ -106,17 +106,17 @@ class KshowmailView : public QSplitter
*/
void refreshSetup();
- KListView* m_pListAccounts;
- KListView* m_pListMessages;
+ TDEListView* m_pListAccounts;
+ TDEListView* m_pListMessages;
private:
- QPixmap* m_pixOk;
+ TQPixmap* m_pixOk;
/**
* Connector to the configuration file
*/
- KConfig* config;
+ TDEConfig* config;
/**
* Reads the some geometry options from the application config file.
@@ -131,10 +131,10 @@ private slots:
* Selects the clicked item and shows the popup menu mail_context_popup defined in
* kshowmailui.rc.
*/
- void slotMessageContext( QListViewItem*, const QPoint&, int );
+ void slotMessageContext( TQListViewItem*, const TQPoint&, int );
- void slotMessageDoubleClicked (QListViewItem*);
- void slotMessageClicked (QListViewItem*);
+ void slotMessageDoubleClicked (TQListViewItem*);
+ void slotMessageClicked (TQListViewItem*);
/**
* Connected with signal rightButtonClicked of m_pListAccounts.
@@ -142,13 +142,13 @@ private slots:
* Selects the clicked item and shows the popup menu account_context_popup defined in
* kshowmailui.rc.
*/
- void slotAccountContext( QListViewItem*, const QPoint &, int );
+ void slotAccountContext( TQListViewItem*, const TQPoint &, int );
/**
* Connected with signal clicked of the account list.
* Activate or deactivate the account, if the user has clicked in the first column
*/
- void slotAccountClicked( QListViewItem*, const QPoint& point, int col );
+ void slotAccountClicked( TQListViewItem*, const TQPoint& point, int col );
signals:
void signalActiveChanged ();
@@ -45,7 +45,7 @@ class ConfigList;
class KshowmailDoc;
/** The KshowmailView class provides the view widget for the KShowMailApp instance.
- * The View instance inherits QWidget as a base class and represents the view object of a KMainWindow.
+ * The View instance inherits TQWidget as a base class and represents the view object of a TDEMainWindow.
* As KshowmailView is part of the document-view model, it needs a reference to the document object
* connected with it by the KShowMailApp class to manipulate and display